@@ -686,9 +686,3 @@ void hd_launcher_tile_reset(HdLauncherTile *tile)
       priv->press_timeout = 0;
     }
 }
-
-void hd_launcher_tile_activate(ClutterActor       *actor)
-{
-	hd_launcher_tile_button_press(actor);
-	hd_launcher_tile_button_release(actor);
-}
